# Paraqus

Paraqus is a python package developed to export simulation results to the .vtk-format. 

## Documentation

The documentation for Paraqus can be found [here](https://paraqus.readthedocs.io/). It also contains information on how to install the software.


## License

Paraqus is released under the [GNU GPLv3](https://choosealicense.com/licenses/gpl-3.0/) license.
